import { Alert, Snackbar } from '@mui/material';
import { useEffect, useState } from 'react';
import ReactDOM from 'react-dom';

const defaultDuration = 2000;

interface NotificationProps {
  message: string;
  type: 'success' | 'error' | 'info' | 'warning';
  duration?: number;
}

interface ConfigProps {
  message: string;
  duration?: number;
}

const Notification = (props: NotificationProps) => {
  const { message, type, duration } = props;
  const [open, setOpen] = useState(false);

  const handleClose = () => {
    setOpen(false);
  };

  useEffect(() => {
    setOpen(true);
  }, []);

  return (
    <Snackbar
      open={open}
      autoHideDuration={duration}
      onClose={handleClose}
      anchorOrigin={{ vertical: 'bottom', horizontal: 'center' }}
    >
      <Alert severity={type} variant="filled" onClose={handleClose}>
        {message}
      </Alert>
    </Snackbar>
  );
};

const notification = {
  dom: null,

  success({ message, duration = defaultDuration }: ConfigProps) {
    const dom = document.createElement('div');
    const JSXdom = (
      <Notification message={message} duration={duration} type="success" />
    );
    ReactDOM.render(JSXdom, dom);
    document.body.appendChild(dom);
  },

  error({ message, duration = defaultDuration }: ConfigProps) {
    const dom = document.createElement('div');
    const JSXdom = (
      <Notification message={message} duration={duration} type="error" />
    );
    ReactDOM.render(JSXdom, dom);
    document.body.appendChild(dom);
  },

  warning({ message, duration = defaultDuration }: ConfigProps) {
    const dom = document.createElement('div');
    const JSXdom = (
      <Notification message={message} duration={duration} type="warning" />
    );
    ReactDOM.render(JSXdom, dom);
    document.body.appendChild(dom);
  },

  info({ message, duration = defaultDuration }: ConfigProps) {
    const dom = document.createElement('div');
    const JSXdom = (
      <Notification message={message} duration={duration} type="warning" />
    );
    ReactDOM.render(JSXdom, dom);
    document.body.appendChild(dom);
  },
};

export default notification;
